#
# spec file for package qt6-wayland
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.8.2
%define short_version 6.8
%define tar_name qtwayland-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor %{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
%ifnarch %{arm} aarch64
%global with_opengl 1
%endif
Name:           qt6-wayland%{?pkg_suffix}
Version:        6.8.2
Release:        1.1
Summary:        Qt 6 Wayland libraries and tools
# The wayland compositor files are GPL-3.0-or-later
License:        GPL-3.0-or-later AND (GPL-2.0-only OR LGPL-3.0-only OR GPL-3.0-or-later)
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-wayland-rpmlintrc
# PATCH-FIX-UPSTREAM
Patch0:         0001-update-wayland_xml-to-version-1_23_0.patch
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel
BuildRequires:  qt6-gui-private-devel
BuildRequires:  qt6-opengl-private-devel
BuildRequires:  qt6-platformsupport-private-devel
BuildRequires:  qt6-qml-private-devel
BuildRequires:  qt6-quick-private-devel
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6Gui) = %{real_version}
BuildRequires:  cmake(Qt6OpenGL) = %{real_version}
BuildRequires:  cmake(Qt6Qml) = %{real_version}
BuildRequires:  cmake(Qt6Quick) = %{real_version}
BuildRequires:  cmake(Qt6Svg) = %{real_version}
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server) >= 1.15
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xkbcommon)
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
The Qt6 Wayland libraries and tools.

%if !%{qt6_docs_flavor}

%package devel
Summary:        Qt6 Wayland development meta package
Requires:       cmake(Qt6WaylandClient) = %{real_version}
Requires:       cmake(Qt6WaylandCompositor) = %{real_version}
# This package contains information on features enabled at build time
Requires:       cmake(Qt6WaylandGlobalPrivate) = %{real_version}

%description devel
This meta-package requires all the qt6-wayland development packages.

%package private-devel
Summary:        Qt6 wayland unstable ABI meta package
Requires:       qt6-waylandclient-private-devel = %{version}
Requires:       qt6-waylandcompositor-private-devel = %{version}
Requires:       cmake(Qt6WaylandEglClientHwIntegrationPrivate) = %{real_version}
Requires:       cmake(Qt6WaylandEglCompositorHwIntegrationPrivate) = %{real_version}
Requires:       cmake(Qt6WlShellIntegrationPrivate) = %{real_version}
BuildArch:      noarch

%description private-devel
This meta-package requires all the qt6-wayland development packages that do not
have any ABI or API guarantees.

%package imports
Summary:        Qt 6 Wayland QML files and plugins

%description imports
QML files and plugins from the Qt 6 Wayland module

%package -n libQt6WaylandClient6
Summary:        Qt 6 WaylandClient library

%description -n libQt6WaylandClient6
The Qt 6 WaylandClient library.

%package -n qt6-waylandclient-devel
Summary:        Development files for the Qt 6 WaylandClient library
Requires:       libQt6WaylandClient6 = %{version}
# qtwaylandscanner is required
Requires:       qt6-wayland = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}
Requires:       cmake(Qt6WaylandCompositor) = %{real_version}
Requires:       cmake(Qt6WaylandGlobalPrivate) = %{real_version}

%description -n qt6-waylandclient-devel
Development files for the Qt6 WaylandClient library.

%package -n qt6-waylandclient-private-devel
Summary:        Non-ABI stable API for the Qt 6 WaylandClient library
Requires:       cmake(Qt6WaylandClient) = %{real_version}
%requires_eq    qt6-core-private-devel
%requires_eq    qt6-gui-private-devel

%description -n qt6-waylandclient-private-devel
This package provides private headers of libQt6WaylandClient that do not have
any ABI or API guarantees.

%package -n libQt6WaylandCompositor6
Summary:        Qt 6 WaylandCompositor library

%description -n libQt6WaylandCompositor6
The Qt 6 WaylandCompositor library.

%package -n qt6-waylandcompositor-devel
Summary:        Development files for the Qt6 WaylandCompositor library
Requires:       libQt6WaylandCompositor6 = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}
Requires:       cmake(Qt6OpenGL) = %{real_version}
Requires:       cmake(Qt6Qml) = %{real_version}
Requires:       cmake(Qt6Quick) = %{real_version}
Requires:       cmake(Qt6WaylandGlobalPrivate) = %{real_version}

%description -n qt6-waylandcompositor-devel
Development files for the Qt6 WaylandCompositor library.

%package -n qt6-waylandcompositor-private-devel
Summary:        Non-ABI stable API for the Qt6 WaylandCompositor library
Requires:       cmake(Qt6WaylandCompositor) = %{real_version}
%requires_eq    qt6-core-private-devel
%requires_eq    qt6-gui-private-devel
%requires_eq    qt6-qml-private-devel
%requires_eq    qt6-quick-private-devel

%description -n qt6-waylandcompositor-private-devel
This package provides private headers of libQt6WaylandCompositor that do not
have any ABI or API guarantees.

%package -n qt6-waylandglobal-private-devel
Summary:        Collection of build features used by qt6-wayland libraries

%description -n qt6-waylandglobal-private-devel
This package contains enabled features information shared by all the
qt6-wayland libraries.

### Private only libraries ###

%package -n libQt6WaylandEglClientHwIntegration6
Summary:        Qt 6 WaylandEglClientHwIntegration library

%description -n libQt6WaylandEglClientHwIntegration6
The Qt 6 WaylandEglClientHwIntegration  library.
This library does not have any ABI or API guarantees.

%package -n qt6-waylandeglclienthwintegration-private-devel
Summary:        Qt 6 WaylandEglClientHwIntegration library - Development files
Requires:       libQt6WaylandEglClientHwIntegration6 = %{version}
Requires:       qt6-waylandclient-private-devel = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}
%requires_eq    qt6-opengl-private-devel

%description -n qt6-waylandeglclienthwintegration-private-devel
Development files for the Qt 6 WaylandEglClientHwIntegration library.
This library does not have any ABI or API guarantees.

%package -n libQt6WaylandEglCompositorHwIntegration6
Summary:        Qt 6 WaylandEglCompositorHwIntegration library

%description -n libQt6WaylandEglCompositorHwIntegration6
The Qt 6 WaylandEglCompositorHwIntegration library.
This library does not have any ABI or API guarantees.

%package -n qt6-waylandeglcompositorhwintegration-private-devel
Summary:        Qt 6 WaylandEglCompositorHwIntegration library - Development files
Requires:       libQt6WaylandEglCompositorHwIntegration6 = %{version}
Requires:       qt6-waylandcompositor-private-devel = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}

%description -n qt6-waylandeglcompositorhwintegration-private-devel
Development files for the Qt 6 WaylandEglCompositorHwIntegration library.
This library does not have any ABI or API guarantees.

%package -n libQt6WlShellIntegration6
Summary:        Qt 6 WlShellIntegration library

%description -n libQt6WlShellIntegration6
The Qt 6 WlShellIntegration library.
This library does not have any ABI or API guarantees.

%package -n qt6-wlshellintegration-private-devel
Summary:        Qt 6 WlShellIntegration library - Development files
Requires:       libQt6WlShellIntegration6 = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}
Requires:       cmake(Qt6WaylandClient) = %{real_version}

%description -n qt6-wlshellintegration-private-devel
Development files for the Qt 6 WlShellIntegration library.
This library does not have any ABI or API guarantees.

%{qt6_examples_package}

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

# Empty file used for the meta packages
cat >> meta_package << EOF
This is a meta package, it does not contain any file
EOF

%build
%cmake_qt6 \
  -DQT_GENERATE_SBOM:BOOL=FALSE

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

# .CMake files are not needed for plugins
rm -r %{buildroot}%{_qt6_cmakedir}/Qt6Gui
rm -r %{buildroot}%{_qt6_cmakedir}/Qt6Qml/QmlPlugins
rm %{buildroot}%{_qt6_cmakedir}/*/*Plugin{Config,Targets}*.cmake

%ldconfig_scriptlets -n libQt6WaylandClient6
%ldconfig_scriptlets -n libQt6WaylandCompositor6
%ldconfig_scriptlets -n libQt6WaylandEglClientHwIntegration6
%ldconfig_scriptlets -n libQt6WaylandEglCompositorHwIntegration6
%ldconfig_scriptlets -n libQt6WlShellIntegration6

%files
%license LICENSES/*
%dir %{_qt6_pluginsdir}/platforms
%{_qt6_libexecdir}/qtwaylandscanner
%{_qt6_pluginsdir}/platforms/libqwayland-*.so
%{_qt6_pluginsdir}/wayland-decoration-client/
%{_qt6_pluginsdir}/wayland-graphics-integration-client/
%{_qt6_pluginsdir}/wayland-graphics-integration-server/
%{_qt6_pluginsdir}/wayland-shell-integration

%files devel
%doc meta_package

%files private-devel
%doc meta_package

%files imports
%{_qt6_qmldir}/QtWayland/

%files -n libQt6WaylandClient6
%{_qt6_libdir}/libQt6WaylandClient.so.*

%files -n qt6-waylandclient-devel
%dir %{_qt6_cmakedir}/Qt6
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtWaylandTestsConfig.cmake
%{_qt6_cmakedir}/Qt6/FindWaylandkms.cmake
%{_qt6_cmakedir}/Qt6WaylandClient/
%{_qt6_cmakedir}/Qt6WaylandScannerTools/
%{_qt6_descriptionsdir}/WaylandClient.json
%{_qt6_includedir}/QtWaylandClient
%{_qt6_libdir}/libQt6WaylandClient.prl
%{_qt6_libdir}/libQt6WaylandClient.so
%{_qt6_metatypesdir}/qt6waylandclient_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_waylandclient.pri
%{_qt6_pkgconfigdir}/Qt6WaylandClient.pc
%exclude %{_qt6_includedir}/QtWaylandClient/%{real_version}

%files -n qt6-waylandclient-private-devel
%{_qt6_includedir}/QtWaylandClient/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_waylandclient_private.pri

%files -n libQt6WaylandCompositor6
%{_qt6_libdir}/libQt6WaylandCompositor.so.*
%{_qt6_libdir}/libQt6WaylandCompositorIviapplication.so.*
%{_qt6_libdir}/libQt6WaylandCompositorPresentationTime.so.*
%{_qt6_libdir}/libQt6WaylandCompositorWLShell.so.*
%{_qt6_libdir}/libQt6WaylandCompositorXdgShell.so.*

%files -n qt6-waylandcompositor-devel
%{_qt6_cmakedir}/Qt6WaylandCompositor/
%{_qt6_cmakedir}/Qt6WaylandCompositorIviapplication/
%{_qt6_cmakedir}/Qt6WaylandCompositorPresentationTime/
%{_qt6_cmakedir}/Qt6WaylandCompositorWLShell/
%{_qt6_cmakedir}/Qt6WaylandCompositorXdgShell/
%{_qt6_descriptionsdir}/WaylandCompositor.json
%{_qt6_descriptionsdir}/WaylandCompositorIviapplication.json
%{_qt6_descriptionsdir}/WaylandCompositorPresentationTime.json
%{_qt6_descriptionsdir}/WaylandCompositorWLShell.json
%{_qt6_descriptionsdir}/WaylandCompositorXdgShell.json
%{_qt6_includedir}/QtWaylandCompositor/
%{_qt6_includedir}/QtWaylandCompositorIviapplication/
%{_qt6_includedir}/QtWaylandCompositorPresentationTime/
%{_qt6_includedir}/QtWaylandCompositorWLShell/
%{_qt6_includedir}/QtWaylandCompositorXdgShell/
%{_qt6_libdir}/libQt6WaylandCompositor.prl
%{_qt6_libdir}/libQt6WaylandCompositor.so
%{_qt6_libdir}/libQt6WaylandCompositorIviapplication.prl
%{_qt6_libdir}/libQt6WaylandCompositorIviapplication.so
%{_qt6_libdir}/libQt6WaylandCompositorPresentationTime.prl
%{_qt6_libdir}/libQt6WaylandCompositorPresentationTime.so
%{_qt6_libdir}/libQt6WaylandCompositorWLShell.prl
%{_qt6_libdir}/libQt6WaylandCompositorWLShell.so
%{_qt6_libdir}/libQt6WaylandCompositorXdgShell.prl
%{_qt6_libdir}/libQt6WaylandCompositorXdgShell.so
%{_qt6_metatypesdir}/qt6waylandcompositor_*_metatypes.json
%{_qt6_metatypesdir}/qt6waylandcompositoriviapplication_*_metatypes.json
%{_qt6_metatypesdir}/qt6waylandcompositorpresentationtime_*_metatypes.json
%{_qt6_metatypesdir}/qt6waylandcompositorwlshell_*_metatypes.json
%{_qt6_metatypesdir}/qt6waylandcompositorxdgshell_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_waylandcompositor.pri
%{_qt6_mkspecsdir}/modules/qt_lib_waylandcompositoriviapplication*.pri
%{_qt6_mkspecsdir}/modules/qt_lib_waylandcompositorpresentationtime*.pri
%{_qt6_mkspecsdir}/modules/qt_lib_waylandcompositorwlshell*.pri
%{_qt6_mkspecsdir}/modules/qt_lib_waylandcompositorxdgshell*.pri
%{_qt6_pkgconfigdir}/Qt6WaylandCompositor.pc
%{_qt6_pkgconfigdir}/Qt6WaylandCompositorIviapplication.pc
%{_qt6_pkgconfigdir}/Qt6WaylandCompositorPresentationTime.pc
%{_qt6_pkgconfigdir}/Qt6WaylandCompositorWLShell.pc
%{_qt6_pkgconfigdir}/Qt6WaylandCompositorXdgShell.pc
%exclude %{_qt6_includedir}/QtWaylandCompositor/%{real_version}

%files -n qt6-waylandcompositor-private-devel
%{_qt6_includedir}/QtWaylandCompositor/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_waylandcompositor_private.pri

%files -n qt6-waylandglobal-private-devel
%{_qt6_cmakedir}/Qt6WaylandGlobalPrivate/
%{_qt6_descriptionsdir}/WaylandGlobalPrivate.json
%{_qt6_includedir}/QtWaylandGlobal/
%{_qt6_mkspecsdir}/modules/qt_lib_waylandglobal_private.pri

### Private only libraries ###

%files -n libQt6WaylandEglClientHwIntegration6
%{_qt6_libdir}/libQt6WaylandEglClientHwIntegration.so.*

%files -n qt6-waylandeglclienthwintegration-private-devel
%{_qt6_cmakedir}/Qt6WaylandEglClientHwIntegrationPrivate/
%{_qt6_descriptionsdir}/WaylandEglClientHwIntegrationPrivate.json
%{_qt6_includedir}/QtWaylandEglClientHwIntegration/
%{_qt6_libdir}/libQt6WaylandEglClientHwIntegration.prl
%{_qt6_libdir}/libQt6WaylandEglClientHwIntegration.so
%{_qt6_metatypesdir}/qt6waylandeglclienthwintegrationprivate_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_wayland_egl_client_hw_integration_private.pri

%files -n libQt6WaylandEglCompositorHwIntegration6
%{_qt6_libdir}/libQt6WaylandEglCompositorHwIntegration.so.*

%files -n qt6-waylandeglcompositorhwintegration-private-devel
%{_qt6_cmakedir}/Qt6WaylandEglCompositorHwIntegrationPrivate/
%{_qt6_descriptionsdir}/WaylandEglCompositorHwIntegrationPrivate.json
%{_qt6_includedir}/QtWaylandEglCompositorHwIntegration/
%{_qt6_libdir}/libQt6WaylandEglCompositorHwIntegration.prl
%{_qt6_libdir}/libQt6WaylandEglCompositorHwIntegration.so
%{_qt6_metatypesdir}/qt6waylandeglcompositorhwintegrationprivate_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_wayland_egl_compositor_hw_integration_private.pri

%files -n libQt6WlShellIntegration6
%{_qt6_libdir}/libQt6WlShellIntegration.so.*

%files -n qt6-wlshellintegration-private-devel
%{_qt6_cmakedir}/Qt6WlShellIntegrationPrivate/
%{_qt6_descriptionsdir}/WlShellIntegrationPrivate.json
%{_qt6_includedir}/QtWlShellIntegration/
%{_qt6_libdir}/libQt6WlShellIntegration.prl
%{_qt6_libdir}/libQt6WlShellIntegration.so
%{_qt6_metatypesdir}/qt6wlshellintegrationprivate_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_wl_shell_integration_private.pri

%endif

%changelog
* Fri Jan 31 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.8.2
  https://www.qt.io/blog/qt-6.8.2-released
- Drop patches, merged upstream:
  * 0001-fix-crash-issue.patch
  * 0001-client-Redo-management-of-tablet-object-proxies.patch
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.1:
  * https://www.qt.io/blog/qt-6.8.1-released
* Thu Nov 28 2024 Christophe Marin <christophe@krop.fr>
- Add patch to fix crash when unplugging a graphics tablet:
  * 0001-client-Redo-management-of-tablet-object-proxies.patch
* Fri Nov  8 2024 Hillwood Yang <hillwood@opensuse.org>
- Add 0001-fix-crash-issue.patch
  fix crash when attach differ shellsurface to the same shellsurfaceitem (boo#1233141)
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0:
  * https://www.qt.io/blog/qt-6.8-released
- Rebase 0001-update-wayland_xml-to-version-1_23_0.patch
* Sat Sep 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.3
  * https://www.qt.io/blog/qt-6.7.3-released
- Drop patches, merged upstream:
  * 0001-Client-Ensure-that-guessed-popup-parent-has-a-shell-.patch
  * 0001-client-Guard-against-windows-being-on-a-null-screen.patch
  * 0002-Client-Improve-thread-safety-determining-window-size.patch
* Wed Aug 28 2024 Hillwood Yang <hillwood@opensuse.org>
- Add patch to fix 'wl_shm' higher than interface version (2 > 1)
  (boo#1229893, QTBUG-126379):
  * 0001-update-wayland_xml-to-version-1_23_0.patch
* Tue Jul 16 2024 Fabian Vogt <fvogt@suse.com>
- Add patches to fix crashes on screens disappearing
  (kde#489072, kde#489180):
  * 0001-client-Guard-against-windows-being-on-a-null-screen.patch
  * 0002-Client-Improve-thread-safety-determining-window-size.patch
* Tue Jul  9 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix certain wayland protocol errors (kde#489259):
  * 0001-Client-Ensure-that-guessed-popup-parent-has-a-shell-.patch
* Wed Jun 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.2:
  * https://www.qt.io/blog/qt-6.7.2-released
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.1:
  * https://www.qt.io/blog/qt-6.7.1-released
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0:
  * https://www.qt.io/blog/qt-6.7-released
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
- Drop patch, merged upstream:
  * client-avoid-creating-decorations-in-the-render-thread.patch
* Wed Feb  7 2024 Fusion Future <qydwhotmail@gmail.com>
- Add patch to fix a frequent crash (kde#479302)
  * client-avoid-creating-decorations-in-the-render-thread.patch
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Fri Jun 30 2023 Christophe Marin <christophe@krop.fr>
- Update subpackages requirements
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
* Mon Apr  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Mon Mar 20 2023 Christophe Marin <christophe@krop.fr>
- Add a _constraints file to fix build issues
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.3:
  * https://www.qt.io/blog/qt-6.4.3-released
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
* Fri Sep  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Mar 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0-rc
- Drop patch, fixed upstream:
  * 0001-CMake-Fix-qtwayland-feature-detection.patch
* Mon Mar 21 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.4
  * https://www.qt.io/blog/qt-6.2.4-released
* Fri Feb  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix features detection:
  * 0001-CMake-Fix-qtwayland-feature-detection.patch
* Mon Jan 31 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.3:
  * https://www.qt.io/blog/qt-6.2.3-released
* Wed Dec  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc2
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Sep  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-beta4
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.3:
  * https://www.qt.io/blog/qt-6.1.3-released
* Fri Jul  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.2. New bugfix release:
  * https://www.qt.io/blog/qt-6.1.2-released
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.1:
  * https://www.qt.io/blog/qt-6.1.1-released
* Thu May  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0:
  * https://www.qt.io/blog/qt-6.1-released
* Fri Apr 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-rc.
* Tue Apr 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta3.
* Wed Mar 31 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.3
  * https://www.qt.io/blog/qt-6.0.3-released
* Fri Mar 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta2
* Tue Mar  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta1
  https://www.qt.io/blog/qt-6.1-beta-released
* Tue Mar  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.2:
  https://www.qt.io/blog/qt-6.0.2-released
* Tue Mar  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.2:
  https://www.qt.io/blog/qt-6.0.2-released
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.1
  https://www.qt.io/blog/qt-6.0.1-released
* Wed Dec 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Move the QML files into a separate package.
* Wed Dec 16 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use a different 'Name' when building the docs flavor.
* Tue Dec  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0:
  * https://www.qt.io/blog/qt-6.0-released
* Tue Dec  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0:
  * https://www.qt.io/blog/qt-6.0-released
* Wed Dec  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Qt 6.0.0 RC2
* Wed Nov 25 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~rc1
* Tue Nov 17 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~beta5
* Tue Nov 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~beta4.
* Tue Oct 20 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0beta1
  https://www.qt.io/blog/qt-6.0-beta-released
* Tue Oct  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0-alpha
  https://www.qt.io/blog/qt-6.0-alpha-released
* Mon Jun  1 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add qt6-wayland.
